import math
from gtts import gTTS
import os
from playsound import playsound
import datetime


def convert(number):
	
	if(number==0):
		words = "Zero"
	else:
		digits = math.log10(number)
		digits = digits+1   
		singles = {}
		singles[0]=""
		singles[1]="One"
		singles[2]="Two"
		singles[3]="Three"
		singles[4]="Four"
		singles[5]="Five"
		singles[6]="Six"
		singles[7]="Seven"
		singles[8]="Eight"
		singles[9]="Nine"

		doubles = {}
		doubles[0] = ""
		doubles[2] = "Twenty"
		doubles[3] = "Thirty"
		doubles[4] = "Forty"
		doubles[5] = "Fifty"
		doubles[6] = "Sixty"
		doubles[7] = "Seventy"
		doubles[8] = "Eighty"
		doubles[9] = "Ninety"

		teens = {}
		teens[0] = "Ten"
		teens[1] = "Eleven"
		teens[2] = "Twelve"
		teens[3] = "Thirteen"
		teens[4] = "Fourteen"
		teens[5] = "Fifteen"
		teens[6] = "Sixteen"
		teens[7] = "Seventeen"
		teens[8] = "Eighteen"
		teens[9] = "Nineteen"

		placevalue = {}
		placevalue[2] = "Hundred,"
		placevalue[3] = "Thousand,"
		placevalue[5] = "Lakh,"
		placevalue[7] = "Crore,"

		temp_num = number
		words = ""
		counter = 0
		digits = int(digits)
		while(counter<digits):
			current = temp_num%10
			if(counter%2==0):
				addition = ""
				if(counter in placevalue.keys() and current!=0):
					addition = placevalue[counter]
				if(counter == 2):
					words = singles[current]+addition+words
				elif(counter == 0):
					if(((temp_num%100)//10)==1):
						words = teens[current]+addition+words
						temp_num = temp_num//10
						counter+=1
					else:
						words = singles[current]+addition+words
						
				else:
					words = doubles[current]+addition+words
				
			else:
				if(counter==1):
					if(current==1):
						words = teens[number%10]+words
					else:
						addition = ""
						if(counter in placevalue.keys()):
							addition = placevalue[counter]
						words = doubles[current]+addition+words
				else:
					addition = ""
					if(counter in placevalue.keys()):
						if(current == 0 and ((temp_num%100)//10)==0):
							addition = ""
						else:
							addition = placevalue[counter]
					if(((temp_num%100)//10)==1):
						words = teens[current]+addition+words
						temp_num = temp_num//10
						counter+=1
					else:
						words = singles[current]+addition+words
			counter+=1
			temp_num = temp_num//10
	tts = gTTS(text=words,lang='en',slow=False)
	name = words+".mp3"
	try:
		tts.save(name)
	except:
		pass
	playsound(name)
	
		


import re
from setuptools import setup

version = '1.0.4'

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

def parse_requirements(file_name):
    requirements = []
    for line in open(file_name, 'r').read().split('\n'):
        if re.match(r'(\s*#)|(\s*$)', line):
            continue
        if re.match(r'\s*-e\s+', line):
            requirements.append(re.sub(r'\s*-e\s+.*#egg=(.*)$', r'\1', line))
        elif re.match(r'\s*-f\s+', line):
            pass
        else:
            requirements.append(line)

    return requirements

package_name='inwords'
base_url = 'https://github.com/s18k/inwords/'
setup(
    name='inwords',
    version=version,
    description='A Python package to spell out a number',
    author='Shreyas Kamath',
    author_email='shreyaskamath18@gmail.com',
    license='GNU General Public License v3.0',
	long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/s18k/inwords',
    
	download_url='{0}/archive/{1}-{2}'.format(base_url, package_name,version),
    packages=['inwords'],
    include_package_data=True,
    zip_safe=False,
    install_requires=parse_requirements("requirements.txt"),
   
)